--- a/wlanutilities/wlanentryplugin/inc/wlanstatusinfo.h Fri May 14 10:30:51 2010 +0300
+++ b/wlanutilities/wlanentryplugin/inc/wlanstatusinfo.h Mon May 24 21:11:39 2010 +0300
@@ -1,19 +1,19 @@
/*
- * Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
- * All rights reserved.
- * This component and the accompanying materials are made available
- * under the terms of "Eclipse Public License v1.0"
- * which accompanies this distribution, and is available
- * at the URL "http://www.eclipse.org/legal/epl-v10.html".
- *
- * Initial Contributors:
- * Nokia Corporation - initial contribution.
- *
- * Contributors:
- *
- * Description:
- *
- */
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0"
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+* WLAN Status Info wrapper for WLAN entry plugin.
+*/
#ifndef WLANSTATUSINFO_H
#define WLANSTATUSINFO_H
@@ -27,6 +27,7 @@
// Forward declarations
class WlanQtUtils;
+class XQSettingsManager;
// External data types
@@ -42,15 +43,15 @@
// Data types
- /**
+ /*!
* WLAN Status value.
*/
enum {
- /** WLAN is configured OFF. */
+ //! WLAN is configured OFF.
WlanStatusOff = 0,
- /** No WLAN connections. */
+ //! No WLAN connections.
WlanStatusIdle,
- /** WLAN IAP is connected. */
+ //! WLAN IAP is connected.
WlanStatusConnected,
};
@@ -58,9 +59,9 @@
~WlanStatusInfo();
- int status();
+ int status() const;
- QString statusText();
+ QString statusText() const;
signals:
@@ -79,18 +80,27 @@
Q_DISABLE_COPY(WlanStatusInfo)
+ bool isWlanOn() const;
+
private slots:
void updateStatus();
private: // data
- WlanQtUtils *mWlanQtUtils; // WlanQtUtils instance.
- QString mStatusText; // WLAN status text.
- int mStatus; // WLAN status value WlanStatus*.
+ //! WlanQtUtils instance.
+ WlanQtUtils *mWlanQtUtils;
+
+ //! Settings manager for platform settings reading, writing & status changes.
+ XQSettingsManager *mSettingsManager;
+
+ //! WLAN status text.
+ QString mStatusText;
+
+ //! WLAN status value WlanStatus*.
+ int mStatus;
// Friend classes
-
};
#endif // WLANSTATUSINFO_H